# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later
"""Tests for PadChest dataset."""

import importlib

import pytest


def id_function(val):
    if isinstance(val, dict):
        return str(val)
    return repr(val)


@pytest.mark.parametrize(
    "split,lenghts",
    [
        # ("idiap.json.bz2", dict(train=96269)),  ## many labels
        ("tb-idiap.json", dict(train=200, test=50)),  # 0: no-tb, 1: tb
        (
            "no-tb-idiap.json.bz2",
            dict(train=54371, validation=4052),
        ),  # 14 labels
        ("cardiomegaly-idiap.json", dict(train=40)),  # 14 labels
    ],
    ids=id_function,  # just changes how pytest prints it
)
def test_protocol_consistency(
    database_checkers, split: str, lenghts: dict[str, int]
):
    from ptbench.config.data.padchest.datamodule import make_split

    database_checkers.check_split(
        make_split(split),
        lengths=lenghts,
        prefixes=("",),
        possible_labels=(0, 1),
    )


# TODO: Improve this to include other protocols
@pytest.mark.skip_if_rc_var_not_set("datadir.padchest")
@pytest.mark.parametrize(
    "dataset",
    [
        "train",
    ],
)
@pytest.mark.parametrize(
    "name",
    [
        "idiap",
    ],
)
def test_loading(database_checkers, name: str, dataset: str):
    datamodule = importlib.import_module(
        f".{name}", "ptbench.config.data.padchest"
    ).datamodule

    datamodule.model_transforms = []  # should be done before setup()
    datamodule.setup("predict")  # sets up all datasets

    loader = datamodule.predict_dataloader()[dataset]

    limit = 3  # limit load checking
    for batch in loader:
        if limit == 0:
            break
        database_checkers.check_loaded_batch(
            batch,
            batch_size=1,
            color_planes=1,
            prefixes=("",),
            possible_labels=(0, 1),
        )
        limit -= 1


# TODO: check size 1024x1024
# TODO: check there are 14 binary labels (0, 1) (in some cases, in others much
# more)...
